==> archive-1.1.2-jy-sources.jar: com/gtis/archive/util/SearchUtils.java <==
package com.gtis.archive.util;

import com.gtis.archive.Constants;
import com.gtis.archive.core.Field;
import org.hibernate.Hibernate;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Restrictions;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * .
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 * @version V1.0, 11-11-29
 */
public class SearchUtils {
    private static String getValue(String s) {
        int i = s.indexOf(",");
        try {
            return i == -1 || i == s.length() - 1 ? null : URLDecoder.decode(s.substring(i + 1), Constants.DEFAULT_CHARSET);
        } catch (UnsupportedEncodingException e) {
            return null;
        }
    }

    private static Criterion conditionToCriterion(Field field, String op, String value) {
        if ("eq".equals(op)) {
            if(isDate(field)){
                return Restrictions.sqlRestriction("to_date("+field.getName()+",yyyy-MM-dd) = ?",value,Hibernate.STRING);
            }else {
                return Restrictions.eq(field.getName(), field.getValue(value));
            }
        } else if ("like".equals(op)) {
            return Restrictions.sqlRestriction("to_char(" + field.getName() + ") like ?", "%" + value + "%", Hibernate.STRING);
//            return Restrictions.like(field.getName(), "%" + value + "%");
        } else if ("ne".equals(op)) {//!=
            return Restrictions.ne(field.getName(), field.getValue(value));
        } else if ("gt".equals(op)) {//>
            if(isDate(field)){
                return Restrictions.sqlRestriction("to_date("+field.getName()+",yyyy-MM-dd) > ?",value,Hibernate.STRING);
            }else {
                return Restrictions.gt(field.getName(), field.getValue(value));
            }
        } else if ("lt".equals(op)) {//<
            if (isDate(field)){
                return Restrictions.sqlRestriction("to_date("+field.getName()+",yyyy-MM-dd) < ?",value,Hibernate.STRING);
            }else {
                return Restrictions.lt(field.getName(), field.getValue(value));
            }
        } else if ("isNull".equals(op)) {
            return Restrictions.isNull(field.getName());
        } else if ("notNull".equals(op)) {
            return Restrictions.isNotNull(field.getName());
        }
        return null;
    }

    public static List<Criterion> conditionToCriterion(Map<String, Field> fieldMap, String condition) {
        List<Criterion> criterions = new ArrayList<Criterion>();
        String[] cs = condition.split(";");
        for (int i = 0; i < cs.length; i += 3) {
            String name = SearchUtils.getValue(cs[i]);
            String op = getValue(cs[i + 1]);
            String value = getValue(cs[i + 2]);
            if (name == null || value == null)
                continue;
            criterions.add(conditionToCriterion(fieldMap.get(name), op, value));
        }
        return criterions;
    }

    private static boolean isDate(Field field){
        return field.getType().name().equals(Date.class.getName());
    }
}

==> archive-1.3.3-jy-sources.jar: com/gtis/archive/util/SearchUtils.java <==
package com.gtis.archive.util;

import com.gtis.archive.Constants;
import com.gtis.archive.core.Field;
import org.hibernate.Hibernate;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Restrictions;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * .
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 * @version V1.0, 11-11-29
 */
public class SearchUtils {
    private static String getValue(String s) {
        int i = s.indexOf(",");
        try {
            return i == -1 || i == s.length() - 1 ? null : URLDecoder.decode(s.substring(i + 1), Constants.DEFAULT_CHARSET);
        } catch (UnsupportedEncodingException e) {
            return null;
        }
    }

    private static Criterion conditionToCriterion(Field field, String op, String value) {
        if ("eq".equals(op)) {
            if(isDate(field)){
                return Restrictions.sqlRestriction("to_date("+field.getName()+",yyyy-MM-dd) = ?",value,Hibernate.STRING);
            }else {
                return Restrictions.eq(field.getName(), field.getValue(value));
            }
        } else if ("like".equals(op)) {
            return Restrictions.sqlRestriction("to_char(" + field.getName() + ") like ?", "%" + value + "%", Hibernate.STRING);
//            return Restrictions.like(field.getName(), "%" + value + "%");
        } else if ("ne".equals(op)) {//!=
            return Restrictions.ne(field.getName(), field.getValue(value));
        } else if ("gt".equals(op)) {//>
            if(isDate(field)){
                return Restrictions.sqlRestriction("to_date("+field.getName()+",yyyy-MM-dd) > ?",value,Hibernate.STRING);
            }else {
                return Restrictions.gt(field.getName(), field.getValue(value));
            }
        } else if ("lt".equals(op)) {//<
            if (isDate(field)){
                return Restrictions.sqlRestriction("to_date("+field.getName()+",yyyy-MM-dd) < ?",value,Hibernate.STRING);
            }else {
                return Restrictions.lt(field.getName(), field.getValue(value));
            }
        } else if ("isNull".equals(op)) {
            return Restrictions.isNull(field.getName());
        } else if ("notNull".equals(op)) {
            return Restrictions.isNotNull(field.getName());
        }
        return null;
    }

    public static List<Criterion> conditionToCriterion(Map<String, Field> fieldMap, String condition) {
        List<Criterion> criterions = new ArrayList<Criterion>();
        String[] cs = condition.split(";");
        for (int i = 0; i < cs.length; i += 3) {
            String name = SearchUtils.getValue(cs[i]);
            String op = getValue(cs[i + 1]);
            String value = getValue(cs[i + 2]);

            if(op.equals("isNull") || op.equals("notNull")){
                criterions.add(conditionToCriterion(fieldMap.get(name), op, value));
                continue;
            }

            if ((name == null || value == null))
                continue;
            criterions.add(conditionToCriterion(fieldMap.get(name), op, value));
        }
        return criterions;
    }

    private static boolean isDate(Field field){
        return field.getType().name().equals(Date.class.getName());
    }
}
